<?php
include_once '../../config/headers.php';
require '../verificar_token.php';

$user_id = verificarToken();

$id = isset($_POST['id']) ? $_POST['id'] : null;

try {
    // Recibir los datos del formulario
    $titulo = isset($_POST['titulo']) ? $_POST['titulo'] : null;
    $descripcion = isset($_POST['descripcion']) ? $_POST['descripcion'] : null;
    $categorias = isset($_POST['categorias']) ? $_POST['categorias'] : null;
    $contenido = isset($_POST['contenido']) ? $_POST['contenido'] : null;

    // Manejo de archivos
    $thumbPath = handleFileUpload('thumb', '../../uploads/blog/', 'thumb_');
    $imagenContenidoPath = handleFileUpload('imagen_contenido', '../../uploads/blog/', 'contenido_');

    if ($id) {
        // Actualizar registro existente
        $query = $db->prepare("
            UPDATE blog SET 
                titulo = :titulo, 
                descripcion = :descripcion, 
                categorias = :categorias, 
                contenido = :contenido, 
                thumb = COALESCE(:thumb, thumb), 
                imagen_contenido = COALESCE(:imagen_contenido, imagen_contenido) 
            WHERE id = :id
        ");
        $query->bindParam(':id', $id, PDO::PARAM_INT);
    } else {
        // Insertar nuevo registro
        $query = $db->prepare("
            INSERT INTO blog (titulo, descripcion, categorias, contenido, thumb, imagen_contenido) 
            VALUES (:titulo, :descripcion, :categorias, :contenido, :thumb, :imagen_contenido)
        ");
    }

    // Asignar valores a los parámetros
    $query->bindParam(':titulo', $titulo);
    $query->bindParam(':descripcion', $descripcion);
    $query->bindParam(':categorias', $categorias);
    $query->bindParam(':contenido', $contenido);
    $query->bindParam(':thumb', $thumbPath);
    $query->bindParam(':imagen_contenido', $imagenContenidoPath);

    if ($query->execute()) {
        echo json_encode(["success" => true, "message" => "Datos guardados correctamente."]);
    } else {
        throw new Exception("Error al guardar los datos.");
    }
} catch (Exception $e) {
    http_response_code(500);
    echo json_encode(["success" => false, "message" => $e->getMessage()]);
}

function handleFileUpload($inputName, $uploadDir, $prefix)
{
    if (isset($_FILES[$inputName]) && $_FILES[$inputName]['error'] === UPLOAD_ERR_OK) {
        $fileName = uniqid($prefix) . '.' . pathinfo($_FILES[$inputName]['name'], PATHINFO_EXTENSION);
        $filePath = $uploadDir . $fileName;
        if (!is_dir($uploadDir) && !mkdir($uploadDir, 0777, true)) {
            throw new Exception("Error al crear el directorio de subida");
        }
        if (move_uploaded_file($_FILES[$inputName]['tmp_name'], $filePath)) {
            return $filePath;
        }
    }
    return null;
}
