<?php
include_once '../../config/headers.php';
require '../verificar_token.php';

// Verifica el token y obtiene el user_id
$user_id = verificarToken();

// Verifica que se haya recibido un archivo de video y la ruta anterior
if (empty($_FILES['video']) || empty($_POST['ruta_old'])) {
    http_response_code(400);
    echo json_encode(["message" => "No se recibió el archivo o la ruta anterior."]);
    exit;
}

$file = $_FILES['video'];
$uploadDir = '../../uploads/videos/';
$oldFilePath = '../../uploads/' . $_POST['ruta_old'];
$idhome_video = $_POST['idhome_video']; 

// Crea el directorio si no existe
if (!is_dir($uploadDir) && !mkdir($uploadDir, 0777, true)) {
    http_response_code(500);
    echo json_encode(["message" => "Error al crear el directorio de subida."]);
    exit;
}

// Genera un nombre de archivo único para evitar sobrescrituras
$newFileName = uniqid('video_') . '.' . pathinfo($file['name'], PATHINFO_EXTENSION);
$newFilePath = $uploadDir . $newFileName;
$dbPath = 'videos/' . $newFileName;

// Mueve el archivo y actualiza la base de datos
try {
    if (move_uploaded_file($file['tmp_name'], $newFilePath)) {
        $stmt = $db->prepare('UPDATE home_video SET ruta = ? WHERE idhome_video = ?');

        if ($stmt->execute([$dbPath, $idhome_video])) {
            // Elimina el archivo antiguo si existe
            if (file_exists($oldFilePath)) {
                unlink($oldFilePath);
            }
            echo json_encode(["message" => "Video subido y actualizado correctamente", "ruta" => $dbPath]);
        } else {
            // Si falla la actualización en la base de datos, elimina el nuevo archivo
            unlink($newFilePath);
            throw new Exception("Error al actualizar la base de datos.");
        }
    } else {
        throw new Exception("Error al subir el archivo.");
    }
} catch (Exception $e) {
    http_response_code(500);
    echo json_encode(["message" => $e->getMessage()]);
}
