<?php
include_once '../../config/headers.php';
require '../verificar_token.php';

// Verifica el token y obtiene el user_id
$user_id = verificarToken();

// Verifica que se haya recibido un archivo de imagen
if (empty($_FILES['image'])) {
    http_response_code(400);
    echo json_encode(["message" => "No se recibió ningún archivo"]);
    exit;
}

$file = $_FILES['image'];
$uploadDir = '../../uploads/banners/';

// Crea el directorio de subida si no existe
if (!is_dir($uploadDir) && !mkdir($uploadDir, 0777, true)) {
    http_response_code(500);
    echo json_encode(["message" => "Error al crear el directorio de subida"]);
    exit;
}

// Genera un nombre de archivo único para evitar sobrescrituras
$newFileName = uniqid('banner_') . '.' . pathinfo($file['name'], PATHINFO_EXTENSION);
$newFilePath = $uploadDir . $newFileName;
$dbPath = 'banners/' . $newFileName;

// Mueve el archivo y guarda la ruta en la base de datos
try {
    if (move_uploaded_file($file['tmp_name'], $newFilePath)) {
        $query = $db->prepare("INSERT INTO home_banners (ruta) VALUES (:ruta)");
        $query->bindParam(":ruta", $dbPath);

        if ($query->execute()) {
            echo json_encode(["message" => "Banner subido correctamente", "ruta" => $dbPath]);
        } else {
            // Si falla la inserción, elimina el archivo subido
            unlink($newFilePath);
            throw new Exception("Error al guardar el banner en la base de datos");
        }
    } else {
        throw new Exception("Error al subir el archivo");
    }
} catch (Exception $e) {
    http_response_code(500);
    echo json_encode(["message" => $e->getMessage()]);
}
