<?php
include_once '../../config/headers.php';
require '../verificar_token.php';

// Verifica el token y obtiene el user_id
$user_id = verificarToken();

// Lee el ID del banner a eliminar desde la solicitud
$input = json_decode(file_get_contents("php://input"), true);
$banner_id = $input['id'] ?? null;

// Valida que el ID esté presente
if (!$banner_id) {
    http_response_code(400);
    echo json_encode(["message" => "ID del banner no proporcionado"]);
    exit;
}

try {
    // Obtén la ruta del banner antes de eliminarlo
    $query = $db->prepare("SELECT ruta FROM home_banners WHERE idhome_banners = :id");
    $query->bindParam(":id", $banner_id, PDO::PARAM_INT);
    $query->execute();
    $banner = $query->fetch(PDO::FETCH_ASSOC);

    if (!$banner) {
        http_response_code(404);
        echo json_encode(["message" => "Banner no encontrado"]);
        exit;
    }

    // Elimina el archivo físico del servidor
    $filePath = '../../uploads/' . $banner['ruta'];
    if (file_exists($filePath) && !unlink($filePath)) {
        throw new Exception("Error al eliminar el archivo físico");
    }

    // Elimina el registro en la base de datos
    $deleteQuery = $db->prepare("DELETE FROM home_banners WHERE idhome_banners = :id");
    $deleteQuery->bindParam(":id", $banner_id, PDO::PARAM_INT);

    if ($deleteQuery->execute()) {
        echo json_encode(["message" => "Banner eliminado correctamente"]);
    } else {
        throw new Exception("Error al eliminar el banner de la base de datos");
    }
} catch (Exception $e) {
    http_response_code(500);
    echo json_encode(["message" => $e->getMessage()]);
}
