<?php
include_once '../../config/headers.php';
require '../verificar_token.php';

$user_id = verificarToken();

$id = isset($_POST['id']) ? $_POST['id'] : null;

try {
    // Recibir los datos del formulario
    $nombre = isset($_POST['nombre']) ? $_POST['nombre'] : null;
    $texto1 = isset($_POST['texto1']) ? $_POST['texto1'] : null;
    $texto2 = isset($_POST['texto2']) ? $_POST['texto2'] : null;
    $valores = isset($_POST['valores']) ? json_decode($_POST['valores'], true) : [];
    $enlaces = isset($_POST['enlaces']) ? json_decode($_POST['enlaces'], true) : [];

    // Manejo de archivos para el banner y logo
    $bannerPath = handleFileUpload('banner', '../../uploads/marca/', 'banner_');
    $logoPath = handleFileUpload('logo', '../../uploads/marca/', 'logo_');

    if ($id) {
        // Actualizar registro existente
        $queryStr = "UPDATE marca SET ";
        $params = [];

        if ($nombre !== null) {
            $queryStr .= "nombre = :nombre, ";
            $params[':nombre'] = $nombre;
        }

        if ($texto1 !== null) {
            $queryStr .= "texto1 = :texto1, ";
            $params[':texto1'] = $texto1;
        }
        
        if ($texto2 !== null) {
            $queryStr .= "texto2 = :texto2, ";
            $params[':texto2'] = $texto2;
        }

        if ($bannerPath !== null) {
            $queryStr .= "banner = :banner, ";
            $params[':banner'] = $bannerPath;
        }

        if ($logoPath !== null) {
            $queryStr .= "logo = :logo, ";
            $params[':logo'] = $logoPath;
        }

        // Remover la última coma y espacio
        $queryStr = rtrim($queryStr, ", ");

        $queryStr .= " WHERE id = :id";
        $params[':id'] = $id;

        $query = $db->prepare($queryStr);
        foreach ($params as $key => &$val) {
            $query->bindParam($key, $val);
        }
    } else {
        // Insertar nuevo registro
        $queryStr = "INSERT INTO marca (nombre, texto1, texto2";
        $queryValues = ") VALUES (:nombre, :texto1, :texto2";
        $params = [
            ':nombre' => $nombre,
            ':texto1' => $texto1,
            ':texto2' => $texto2
        ];

        if ($bannerPath !== null) {
            $queryStr .= ", banner";
            $queryValues .= ", :banner";
            $params[':banner'] = $bannerPath;
        }

        if ($logoPath !== null) {
            $queryStr .= ", logo";
            $queryValues .= ", :logo";
            $params[':logo'] = $logoPath;
        }

        $queryStr .= $queryValues . ")";
        $query = $db->prepare($queryStr);
        foreach ($params as $key => &$val) {
            $query->bindParam($key, $val);
        }
    }

    if ($query->execute()) {
        // Obtener el ID de la marca recién creada o actualizada
        $marcaId = $id ? $id : $db->lastInsertId();

        // Guardar valores
        if (!empty($valores)) {
            saveValores($marcaId, $valores);
        }

        // Guardar enlaces
        if (!empty($enlaces)) {
            saveEnlaces($marcaId, $enlaces);
        }

        echo json_encode(["success" => true, "message" => "Datos guardados correctamente."]);
    } else {
        throw new Exception("Error al guardar los datos.");
    }
} catch (Exception $e) {
    http_response_code(500);
    echo json_encode(["success" => false, "message" => $e->getMessage()]);
}

// Función para manejar la subida de archivos
function handleFileUpload($inputName, $uploadDir, $prefix)
{
    if (isset($_FILES[$inputName]) && $_FILES[$inputName]['error'] === UPLOAD_ERR_OK) {
        $fileName = uniqid($prefix) . '.' . pathinfo($_FILES[$inputName]['name'], PATHINFO_EXTENSION);
        $filePath = $uploadDir . $fileName;
        if (!is_dir($uploadDir) && !mkdir($uploadDir, 0777, true)) {
            throw new Exception("Error al crear el directorio de subida");
        }
        if (move_uploaded_file($_FILES[$inputName]['tmp_name'], $filePath)) {
            return $filePath;
        }
    }
    return null;
}

// Función para guardar valores
function saveValores($marcaId, $valores)
{
    global $db;
    if (!empty($valores)) {
        $query = $db->prepare("DELETE FROM valores WHERE marca_id = :marca_id");
        $query->bindParam(':marca_id', $marcaId, PDO::PARAM_INT);
        $query->execute();

        foreach ($valores as $index => $valor) {
            $titulo = $valor['titulo'];
            $descripcion = $valor['descripcion'];
            $imagenPath = isset($_FILES["valor_$index"]) && $_FILES["valor_$index"]['error'] === UPLOAD_ERR_OK
                ? handleFileUpload("valor_$index", '../../uploads/marca/valores/', 'valor_')
                : (isset($_POST["valor_$index" . "_imagen"]) ? $_POST["valor_$index" . "_imagen"] : null);

            $queryStr = "INSERT INTO valores (marca_id, titulo, descripcion";
            $queryValues = ") VALUES (:marca_id, :titulo, :descripcion";
            $params = [
                ':marca_id' => $marcaId,
                ':titulo' => $titulo,
                ':descripcion' => $descripcion,
            ];

            if ($imagenPath) {
                $queryStr .= ", imagen";
                $queryValues .= ", :imagen";
                $params[':imagen'] = $imagenPath;
            }

            $queryStr .= $queryValues . ")";
            $query = $db->prepare($queryStr);
            foreach ($params as $key => &$val) {
                $query->bindParam($key, $val);
            }
            $query->execute();
        }
    }
}

// Función para guardar enlaces
function saveEnlaces($marcaId, $enlaces)
{
    global $db;
    if (!empty($enlaces)) {
        $query = $db->prepare("DELETE FROM enlaces WHERE marca_id = :marca_id");
        $query->bindParam(':marca_id', $marcaId, PDO::PARAM_INT);
        $query->execute();

        foreach ($enlaces as $index => $enlace) {
            $titulo = $enlace['titulo'];
            $descripcion = $enlace['descripcion'];
            $link = $enlace['link'];
            $imagenPath = isset($_FILES["enlace_$index"]) && $_FILES["enlace_$index"]['error'] === UPLOAD_ERR_OK
                ? handleFileUpload("enlace_$index", '../../uploads/marca/enlaces/', 'enlace_')
                : (isset($_POST["enlace_$index" . "_imagen"]) ? $_POST["enlace_$index" . "_imagen"] : null);

            $queryStr = "INSERT INTO enlaces (marca_id, titulo, descripcion, link";
            $queryValues = ") VALUES (:marca_id, :titulo, :descripcion, :link";
            $params = [
                ':marca_id' => $marcaId,
                ':titulo' => $titulo,
                ':descripcion' => $descripcion,
                ':link' => $link,
            ];

            if ($imagenPath) {
                $queryStr .= ", imagen";
                $queryValues .= ", :imagen";
                $params[':imagen'] = $imagenPath;
            }

            $queryStr .= $queryValues . ")";
            $query = $db->prepare($queryStr);
            foreach ($params as $key => &$val) {
                $query->bindParam($key, $val);
            }
            $query->execute();
        }
    }
}
