<?php
include_once '../../config/headers.php';
require '../verificar_token.php';

$user_id = verificarToken();

$id = isset($_GET['id']) ? intval($_GET['id']) : null;

if ($id === null) {
    http_response_code(400);
    echo json_encode(["success" => false, "message" => "ID de marca no proporcionado."]);
    exit;
}

try {
    // Obtener datos de la marca
    $query = $db->prepare("SELECT id, nombre, texto1, texto2, banner, logo FROM marca WHERE id = :id");
    $query->bindParam(':id', $id, PDO::PARAM_INT);
    $query->execute();

    $marca = $query->fetch(PDO::FETCH_ASSOC);

    if (!$marca) {
        http_response_code(404);
        echo json_encode(["success" => false, "message" => "Marca no encontrada."]);
        exit;
    }

    // Obtener valores de la marca
    $query = $db->prepare("SELECT id, titulo, descripcion, imagen FROM valores WHERE marca_id = :marca_id");
    $query->bindParam(':marca_id', $id, PDO::PARAM_INT);
    $query->execute();
    $valores = $query->fetchAll(PDO::FETCH_ASSOC);

    // Obtener enlaces de la marca
    $query = $db->prepare("SELECT id, titulo, descripcion, link, imagen FROM enlaces WHERE marca_id = :marca_id");
    $query->bindParam(':marca_id', $id, PDO::PARAM_INT);
    $query->execute();
    $enlaces = $query->fetchAll(PDO::FETCH_ASSOC);

    // Combinar datos
    $marca['valores'] = $valores;
    $marca['enlaces'] = $enlaces;

    echo json_encode(["success" => true, "data" => $marca]);
} catch (PDOException $e) {
    http_response_code(500);
    echo json_encode(["success" => false, "message" => "Error en el servidor: " . $e->getMessage()]);
}
