<?php
include_once '../../config/headers.php';
require '../verificar_token.php';

$user_id = verificarToken();

// Verifica los campos requeridos
if (empty($_POST['history']) && empty($_FILES['whoWeAreImage']) && empty($_FILES['videoFile']) && empty($_FILES['ourHistoryImage']) && empty($_FILES['accoWorldImage']) && empty($_FILES['videoConocenos'])) {
    http_response_code(400);
    echo json_encode(["message" => "No se recibieron datos para guardar"]);
    exit;
}

// Directorio de subida de archivos
$uploadDir = '../../uploads/nosotros/';

// Función para subir archivos
function uploadFile($file, $dir, $prefix)
{
    if (!empty($file) && $file['error'] === UPLOAD_ERR_OK) {
        $ext = pathinfo($file['name'], PATHINFO_EXTENSION);
        $newFileName = uniqid($prefix) . '.' . $ext;
        $newFilePath = $dir . $newFileName;
        $dbPath = str_replace('../../uploads/', '', $newFilePath);

        if (!is_dir($dir) && !mkdir($dir, 0777, true)) {
            throw new Exception("Error al crear el directorio de subida");
        }

        if (move_uploaded_file($file['tmp_name'], $newFilePath)) {
            return $dbPath;
        } else {
            throw new Exception("Error al subir el archivo $prefix");
        }
    }
    return null;
}

// Obtener las rutas actuales en la base de datos
$query = $db->prepare("SELECT whoWeAreImage, videoFile, ourHistoryImage, accoWorldImage, videoConocenos  FROM organization_content WHERE id = 1");
$query->execute();
$currentFiles = $query->fetch(PDO::FETCH_ASSOC);

// Subida de archivos
try {
    $history = $_POST['history'] ?? '';

    // Subir y reemplazar archivos antiguos
    $whoWeAreImage = !empty($_FILES['whoWeAreImage']) ? uploadFile($_FILES['whoWeAreImage'], $uploadDir . 'whoWeAre/', 'whoWeAre_') : null;
    $videoFile = !empty($_FILES['videoFile']) ? uploadFile($_FILES['videoFile'], $uploadDir . 'videos/', 'video_') : null;
    $videoConocenos = !empty($_FILES['videoConocenos']) ? uploadFile($_FILES['videoConocenos'], $uploadDir . 'videos/', 'videoConocenos_') : null;
    $ourHistoryImage = !empty($_FILES['ourHistoryImage']) ? uploadFile($_FILES['ourHistoryImage'], $uploadDir . 'ourHistory/', 'ourHistory_') : null;
    $accoWorldImage = !empty($_FILES['accoWorldImage']) ? uploadFile($_FILES['accoWorldImage'], $uploadDir . 'accoWorld/', 'accoWorld_') : null;

    // Eliminar archivos antiguos si se subieron nuevos
    function deleteFile($filePath)
    {
        $fullPath = '../../uploads/' . $filePath;
        if (file_exists($fullPath)) {
            unlink($fullPath);
        }
    }

    if ($whoWeAreImage && $currentFiles['whoWeAreImage']) deleteFile($currentFiles['whoWeAreImage']);
    if ($videoFile && $currentFiles['videoFile']) deleteFile($currentFiles['videoFile']);
    if ($videoConocenos && $currentFiles['videoConocenos']) deleteFile($currentFiles['videoConocenos']);
    if ($ourHistoryImage && $currentFiles['ourHistoryImage']) deleteFile($currentFiles['ourHistoryImage']);
    if ($accoWorldImage && $currentFiles['accoWorldImage']) deleteFile($currentFiles['accoWorldImage']);

    // Guardar en la base de datos
    $query = $db->prepare("UPDATE organization_content SET history = :history, whoWeAreImage = COALESCE(:whoWeAreImage, whoWeAreImage), videoFile = COALESCE(:videoFile, videoFile), ourHistoryImage = COALESCE(:ourHistoryImage, ourHistoryImage), accoWorldImage = COALESCE(:accoWorldImage, accoWorldImage), videoConocenos = COALESCE(:videoConocenos, videoConocenos)WHERE id = 1");
    $query->bindParam(':history', $history);
    $query->bindParam(':whoWeAreImage', $whoWeAreImage);
    $query->bindParam(':videoFile', $videoFile);
    $query->bindParam(':ourHistoryImage', $ourHistoryImage);
    $query->bindParam(':accoWorldImage', $accoWorldImage);
    $query->bindParam(':videoConocenos', $videoConocenos);


    if ($query->execute()) {
        echo json_encode(["message" => "Datos guardados correctamente"]);
    } else {
        throw new Exception("Error al guardar los datos en la base de datos");
    }
} catch (Exception $e) {
    http_response_code(500);
    echo json_encode(["message" => $e->getMessage()]);
}
