<?php
include_once '../../config/headers.php';
require '../verificar_token.php';

//$user_id = verificarToken();

$id = isset($_POST['id']) ? $_POST['id'] : null;

try {
    // Verificar y conectar a la base de datos
    global $db; // Asegúrate de que $db esté correctamente inicializado.

    // Recibir los datos del formulario
    $activo = $_POST['activo'] ?? null;
    $nombre = $_POST['nombre'] ?? null;
    $descripcion = $_POST['descripcion'] ?? null;
    $categoria = $_POST['categoria'] ?? null;
    $marca = $_POST['marca'] ?? null;
    $sku = $_POST['sku'] ?? null;
    $link_amazon = $_POST['link_amazon'] ?? null;
    $link_ml = $_POST['link_ml'] ?? null;
    $descripcion_complementaria = $_POST['descripcion_complementaria'] ?? null;

    // Manejo de archivos para la imagen complementaria e infografía
    $imagen_complementariaPath = handleFileUpload('imagen_complementaria', '../../uploads/productos/', 'complementaria_');
    $infografiaPath = handleFileUpload('infografia', '../../uploads/productos/', 'infografia_');

    if ($id) {
        // Actualizar registro existente
        $queryStr = "UPDATE productos SET ";
        $params = [];

        // Construcción dinámica de la consulta
        $fieldsToUpdate = [
            'activo' => $activo,
            'nombre' => $nombre,
            'descripcion' => $descripcion,
            'categoria' => $categoria,
            'marca' => $marca,
            'sku' => $sku,
            'link_amazon' => $link_amazon,
            'link_ml' => $link_ml,
            'imagen_complementaria' => $imagen_complementariaPath,
            'descripcion_complementaria' => $descripcion_complementaria,
            'infografia' => $infografiaPath
        ];

        foreach ($fieldsToUpdate as $field => $value) {
            if ($value !== null) {
                $queryStr .= "$field = :$field, ";
                $params[":$field"] = $value;
            }
        }

        $queryStr = rtrim($queryStr, ", ");
        $queryStr .= " WHERE id = :id";
        $params[':id'] = $id;

        $query = $db->prepare($queryStr);
        foreach ($params as $key => &$val) {
            $query->bindParam($key, $val);
        }
    } else {
        // Insertar nuevo registro
        $queryStr = "INSERT INTO productos (activo, nombre, descripcion, categoria, marca, sku, link_amazon, link_ml, imagen_complementaria, descripcion_complementaria, infografia) 
        VALUES (:activo, :nombre, :descripcion, :categoria, :marca, :sku, :link_amazon, :link_ml, :imagen_complementaria, :descripcion_complementaria, :infografia)";
        $params = [
            ':activo' => $activo,
            ':nombre' => $nombre,
            ':descripcion' => $descripcion,
            ':categoria' => $categoria,
            ':marca' => $marca,
            ':sku' => $sku,
            ':link_amazon' => $link_amazon,
            ':link_ml' => $link_ml,
            ':imagen_complementaria' => $imagen_complementariaPath,
            ':descripcion_complementaria' => $descripcion_complementaria,
            ':infografia' => $infografiaPath,
        ];

        $query = $db->prepare($queryStr);
        foreach ($params as $key => &$val) {
            $query->bindParam($key, $val);
        }
    }

    if ($query->execute()) {
        $productoId = $id ?: $db->lastInsertId();

        // Guardar imágenes
        if (isset($_POST['imagenes']) && !empty($_POST['imagenes'])) {
            $imagenes = is_string($_POST['imagenes']) ? json_decode($_POST['imagenes'], true) : $_POST['imagenes'];
            saveImages($productoId, $imagenes, 'imagenes');
        }

        // Guardar imágenes pequeñas
        if (isset($_POST['imagenes_pequenas']) && !empty($_POST['imagenes_pequenas'])) {
            $imagenes_pequenas = is_string($_POST['imagenes_pequenas']) ? json_decode($_POST['imagenes_pequenas'], true) : $_POST['imagenes_pequenas'];
            saveImages($productoId, $imagenes_pequenas, 'imagenes_pequenas');
        }


        echo json_encode(["success" => true, "message" => "Datos guardados correctamente."]);
    } else {
        throw new Exception("Error al guardar los datos.");
    }
} catch (Exception $e) {
    http_response_code(500);
    echo json_encode(["success" => false, "message" => $e->getMessage()]);
}

function handleFileUpload($inputName, $uploadDir, $prefix)
{
    if (isset($_FILES[$inputName]) && $_FILES[$inputName]['error'] === UPLOAD_ERR_OK) {
        $fileName = uniqid($prefix) . '.' . pathinfo($_FILES[$inputName]['name'], PATHINFO_EXTENSION);
        $filePath = $uploadDir . $fileName;

        if (!is_dir($uploadDir) && !mkdir($uploadDir, 0777, true)) {
            throw new Exception("Error al crear el directorio de subida");
        }
        if (move_uploaded_file($_FILES[$inputName]['tmp_name'], $filePath)) {
            return $filePath;
        }
    }
    return null;
}

function saveImages($productoId, $imagenes, $tableName)
{
    global $db;
    $query = $db->prepare("DELETE FROM $tableName WHERE producto_id = :producto_id");
    $query->bindParam(':producto_id', $productoId, PDO::PARAM_INT);
    $query->execute();

    foreach ($imagenes as $index => $imagen) {
        $titulo = $imagen['titulo'];
        $descripcion = $imagen['descripcion'];
        $archivo = isset($_FILES["imagen_$tableName" . "_$index" . "_archivo"]) && $_FILES["imagen_$tableName" . "_$index" . "_archivo"]['error'] === UPLOAD_ERR_OK
            ? handleFileUpload("imagen_$tableName" . "_$index" . "_archivo", "../../uploads/producto/$tableName/", "imagen_")
            : (isset($_POST["imagen_$tableName" . "_$index" . "_imagen_old"]) ? $_POST["imagen_$tableName" . "_$index" . "_imagen_old"] : null);

        $queryStr = "INSERT INTO $tableName (producto_id, titulo, descripcion, archivo) VALUES (:producto_id, :titulo, :descripcion, :archivo)";
        $params = [
            ':producto_id' => $productoId ?? null,
            ':titulo' => $titulo ?? null,
            ':descripcion' => $descripcion ?? null,
            ':archivo' => $archivo ?? null,
        ];

        $query = $db->prepare($queryStr);
        foreach ($params as $key => &$val) {
            $query->bindParam($key, $val);
        }
        $query->execute();
    }
}
